from setuptools import setup

setup(name='yyggtest',
      version='0.1',
      description='trying to upload yyggtest',
      url='https://github.com/YueGan/random_walker',
      author='GG',
      author_email='gg@gg.com',
      license='MIT',
      packages=['yyggtest'],
      zip_safe=False)